Chapter 2: Modeling
===================

In chapter 2, we'll take you through how to model galaxies using a non-linear search.

The chapter contains the following tutorials:

`Tutorial 1: Data <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_1_data.ipynb>`_
- Loading and inspecting telescope imaging data of a galaxy.

`Tutorial 2: Fitting <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_2_fitting.ipynb>`_
- Fitting data with a galaxy model.

`Tutorial 3: Non-linear Search <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_3_non_linear_search.ipynb>`_
- How a non-linear search is used to fit a model.

`Tutorial 4: Parameter Space And Priors <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_4_parameter_space_and_priors.ipynb>`_
- The Concepts of a parameter space and priors.

`Tutorial 5: Realism and Complexity <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_5_realism_and_complexity.ipynb>`_
- Finding a balance between realism and complexity when composing and fitting a model.

`Tutorial 6: Dealing with Failure <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_6_dealing_with_failure.ipynb>`_
- What to do when PyAutoGalaxy finds an inaccurate model.

`Tutorial 7: Linear Profiles <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_7_linear_profiles.ipynb>`_
- Light profiles which capture complex morphologies in a reduced number of non-linear parameters.

`Tutorial 8: Masking <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_8_masking.ipynb>`_
- How to mask your data to improve the model.

`Tutorial 9: Results <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_9_results.ipynb>`_
- Overview of the results available after successfully fitting a model.

`Tutorial 10: Need for Speed <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_2_modeling/tutorial_10_need_for_speed.ipynb>`_
- How to fit complex models whilst balancing efficiency and run-time.

